from setuptools import setup, find_packages


setup(
    name='awis-py',
    version='0.0.1',
    url='https://github.com/whistlebee/awis-py',
    packages=find_packages(),
    python_requires='>=3.6'
)
